pub struct DocFileWrapper {
pub file: PathBuf,
pub doc_filename: DocFileName,
pub content: Option<Value>,
}Expand description
This wrapper is used to extend a docfile with “external” data such as information we can find in the filename itself, that is:
- pr number
- title
Fields
file: PathBufThe file path
doc_filename: DocFileNameThe filename
content: Option<Value>The content of the PRDoc
Implementations