Schema used by prdoc for its validation
prdoc does not really care about the schema itself and the data is not used or loaded. The schema is stored in the repository and embedded into the cli for convenience. The various commands do check that files comply with the schema but nothing more. That also means that the schema can be adjusted at any time without impact on the code.
Structs
- The schema embedded in prdoc.
Constants
- Default file extension
- Default schema for the validation of data provided by developers